# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/planetarypy',
                'doc_host': 'https://michaelaye.github.io',
                'git_url': 'https://github.com/michaelaye/nbplanetary',
                'lib_path': 'planetarypy'},
  'syms': { 'planetarypy.ciss': { 'planetarypy.ciss.ISSOpus': ('cassini_iss.html#issopus', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.__init__': ('cassini_iss.html#__init__', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.__repr__': ('cassini_iss.html#__repr__', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.calib_data_url': ('cassini_iss.html#calib_data_url', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.calib_label_url': ('cassini_iss.html#calib_label_url', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.download_calib': ('cassini_iss.html#download_calib', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.download_raw': ('cassini_iss.html#download_raw', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.local_calib_label_path': ( 'cassini_iss.html#local_calib_label_path',
                                                                                       'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.local_calib_path': ('cassini_iss.html#local_calib_path', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.local_data_path': ('cassini_iss.html#local_data_path', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.local_folder': ('cassini_iss.html#local_folder', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.local_label_path': ('cassini_iss.html#local_label_path', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.query_pid': ('cassini_iss.html#query_pid', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.raw_data_url': ('cassini_iss.html#raw_data_url', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.raw_label_url': ('cassini_iss.html#raw_label_url', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.raw_prefix_fmt_url': ( 'cassini_iss.html#raw_prefix_fmt_url',
                                                                                   'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.raw_tlmtab_url': ('cassini_iss.html#raw_tlmtab_url', 'planetarypy/ciss.py'),
                                  'planetarypy.ciss.ISSOpus.volume': ('cassini_iss.html#volume', 'planetarypy/ciss.py')},
            'planetarypy.config': { 'planetarypy.config.Config': ('config.html#config', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.__init__': ('config.html#__init__', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.__repr__': ('config.html#__repr__', 'planetarypy/config.py'),
                                    'planetarypy.config.Config._copy_clean_to_resource': ( 'config.html#_copy_clean_to_resource',
                                                                                           'planetarypy/config.py'),
                                    'planetarypy.config.Config.ask_storage_root': ('config.html#ask_storage_root', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.d': ('config.html#d', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.get_value': ('config.html#get_value', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.list_indexes': ('config.html#list_indexes', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.list_instruments': ('config.html#list_instruments', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.missions': ('config.html#missions', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.populate_timestamps': ( 'config.html#populate_timestamps',
                                                                                       'planetarypy/config.py'),
                                    'planetarypy.config.Config.read_config': ('config.html#read_config', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.save': ('config.html#save', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.set_value': ('config.html#set_value', 'planetarypy/config.py'),
                                    'planetarypy.config.Config.update_missions': ('config.html#update_missions', 'planetarypy/config.py')},
            'planetarypy.ctx': { 'planetarypy.ctx.CTX': ('ctx.html#ctx', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.__init__': ('ctx.html#__init__', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.__repr__': ('ctx.html#__repr__', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.__str__': ('ctx.html#__str__', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.cal_path': ('ctx.html#cal_path', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.calib_pipeline': ('ctx.html#calib_pipeline', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.calibrate': ('ctx.html#calibrate', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.cub_path': ('ctx.html#cub_path', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.destripe': ('ctx.html#destripe', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.destripe_path': ('ctx.html#destripe_path', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.do_destripe': ('ctx.html#do_destripe', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.isis_import': ('ctx.html#isis_import', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.pid': ('ctx.html#pid', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.plot_calibrated': ('ctx.html#plot_calibrated', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.plot_da': ('ctx.html#plot_da', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.proc_folder': ('ctx.html#proc_folder', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.read_calibrated': ('ctx.html#read_calibrated', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.read_edr': ('ctx.html#read_edr', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTX.spice_init': ('ctx.html#spice_init', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR': ('ctx.html#ctxedr', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.__init__': ('ctx.html#__init__', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.download': ('ctx.html#download', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.meta': ('ctx.html#meta', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.pid': ('ctx.html#pid', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.source_folder': ('ctx.html#source_folder', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.source_path': ('ctx.html#source_path', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.url': ('ctx.html#url', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDR.volume': ('ctx.html#volume', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection': ('ctx.html#ctxedrcollection', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection.__init__': ('ctx.html#__init__', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection.calib_exist_check': ('ctx.html#calib_exist_check', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection.calibrate_collection': ( 'ctx.html#calibrate_collection',
                                                                                            'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection.download_collection': ( 'ctx.html#download_collection',
                                                                                           'planetarypy/ctx.py'),
                                 'planetarypy.ctx.CTXEDRCollection.get_urls': ('ctx.html#get_urls', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.catch_isis_error': ('ctx.html#catch_isis_error', 'planetarypy/ctx.py'),
                                 'planetarypy.ctx.ctx_calib': ('ctx.html#ctx_calib', 'planetarypy/ctx.py')},
            'planetarypy.db': {},
            'planetarypy.diviner': { 'planetarypy.diviner.DataManager': ('diviner.html#datamanager', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.__init__': ('diviner.html#__init__', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.base_url': ('diviner.html#base_url', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.download': ('diviner.html#download', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.local_path': ('diviner.html#local_path', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.url': ('diviner.html#url', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.volume': ('diviner.html#volume', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.year': ('diviner.html#year', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.yearmonth': ('diviner.html#yearmonth', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.DataManager.yearmonthday': ( 'diviner.html#yearmonthday',
                                                                                       'planetarypy/diviner.py'),
                                     'planetarypy.diviner.L1AHeader': ('diviner.html#l1aheader', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.get_data_path': ('diviner.html#get_data_path', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.parse_header_line': ('diviner.html#parse_header_line', 'planetarypy/diviner.py'),
                                     'planetarypy.diviner.read_l1a_data': ('diviner.html#read_l1a_data', 'planetarypy/diviner.py')},
            'planetarypy.exceptions': { 'planetarypy.exceptions.Error': ('exceptions.html#error', 'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.GeoTransformNotSetError': ( 'exceptions.html#geotransformnotseterror',
                                                                                            'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.KMASpiceError': ( 'exceptions.html#kmaspiceerror',
                                                                                  'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.ObserverNotSetError': ( 'exceptions.html#observernotseterror',
                                                                                        'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.ObserverNotSetError.__str__': ( 'exceptions.html#__str__',
                                                                                                'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.ProjectionNotSetError': ( 'exceptions.html#projectionnotseterror',
                                                                                          'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.SPointNotSetError': ( 'exceptions.html#spointnotseterror',
                                                                                      'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.SPointNotSetError.__str__': ( 'exceptions.html#__str__',
                                                                                              'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.SomethingNotSetError': ( 'exceptions.html#somethingnotseterror',
                                                                                         'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.SomethingNotSetError.__init__': ( 'exceptions.html#__init__',
                                                                                                  'planetarypy/exceptions.py'),
                                        'planetarypy.exceptions.SomethingNotSetError.__str__': ( 'exceptions.html#__str__',
                                                                                                 'planetarypy/exceptions.py')},
            'planetarypy.geotools': { 'planetarypy.geotools.ImgData': ('geotools.html#imgdata', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.__init__': ('geotools.html#__init__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData._read_data': ('geotools.html#_read_data', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.add_scalebar': ( 'geotools.html#add_scalebar',
                                                                                     'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.convert_to_uint8': ( 'geotools.html#convert_to_uint8',
                                                                                         'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.normalize': ('geotools.html#normalize', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.read_all': ('geotools.html#read_all', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.read_center_window': ( 'geotools.html#read_center_window',
                                                                                           'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.read_cropped_by_n': ( 'geotools.html#read_cropped_by_n',
                                                                                          'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.read_window': ('geotools.html#read_window', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.show': ('geotools.html#show', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.window_coords_to_lonlat': ( 'geotools.html#window_coords_to_lonlat',
                                                                                                'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.window_coords_to_meter': ( 'geotools.html#window_coords_to_meter',
                                                                                               'planetarypy/geotools.py'),
                                      'planetarypy.geotools.ImgData.window_coords_to_pixel': ( 'geotools.html#window_coords_to_pixel',
                                                                                               'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point': ('geotools.html#point', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.__add__': ('geotools.html#__add__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.__init__': ('geotools.html#__init__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.__repr__': ('geotools.html#__repr__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.__str__': ('geotools.html#__str__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.calculate_azimuth': ( 'geotools.html#calculate_azimuth',
                                                                                        'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.coords': ('geotools.html#coords', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.copy_geodata': ('geotools.html#copy_geodata', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.lonlat_to_meter': ( 'geotools.html#lonlat_to_meter',
                                                                                      'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.lonlat_to_pixel': ( 'geotools.html#lonlat_to_pixel',
                                                                                      'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.lonlats': ('geotools.html#lonlats', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.meter_to_lonlat': ( 'geotools.html#meter_to_lonlat',
                                                                                      'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.meter_to_pixel': ( 'geotools.html#meter_to_pixel',
                                                                                     'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.pixel_to_lonlat': ( 'geotools.html#pixel_to_lonlat',
                                                                                      'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.pixel_to_meter': ( 'geotools.html#pixel_to_meter',
                                                                                     'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.pixels': ('geotools.html#pixels', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Point.shift_to_center': ( 'geotools.html#shift_to_center',
                                                                                      'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window': ('geotools.html#window', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.__init__': ('geotools.html#__init__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.__repr__': ('geotools.html#__repr__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.__str__': ('geotools.html#__str__', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.copy': ('geotools.html#copy', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.get_corners_from_center': ( 'geotools.html#get_corners_from_center',
                                                                                               'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.get_extent': ('geotools.html#get_extent', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.get_gdal_window': ( 'geotools.html#get_gdal_window',
                                                                                       'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.get_lr_from_width': ( 'geotools.html#get_lr_from_width',
                                                                                         'planetarypy/geotools.py'),
                                      'planetarypy.geotools.Window.usage': ('geotools.html#usage', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.calculate_image_azimuth': ( 'geotools.html#calculate_image_azimuth',
                                                                                        'planetarypy/geotools.py'),
                                      'planetarypy.geotools.calculate_image_north_azimuth': ( 'geotools.html#calculate_image_north_azimuth',
                                                                                              'planetarypy/geotools.py'),
                                      'planetarypy.geotools.debug_srs': ('geotools.html#debug_srs', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.get_north_shifted_point': ( 'geotools.html#get_north_shifted_point',
                                                                                        'planetarypy/geotools.py'),
                                      'planetarypy.geotools.get_sun_angles': ('geotools.html#get_sun_angles', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.pixel_to_meter': ('geotools.html#pixel_to_meter', 'planetarypy/geotools.py'),
                                      'planetarypy.geotools.shift_to_center': ('geotools.html#shift_to_center', 'planetarypy/geotools.py')},
            'planetarypy.hirise': { 'planetarypy.hirise.BG_PRODUCT': ('hirise.html#bg_product', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.BG_PRODUCT.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT': ('hirise.html#color_product', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.download': ('hirise.html#download', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.local_path': ('hirise.html#local_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.meta': ('hirise.html#meta', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.plot_da': ('hirise.html#plot_da', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.product_id': ('hirise.html#product_id', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.read': ('hirise.html#read', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.remote_path': ('hirise.html#remote_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.show': ('hirise.html#show', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.COLOR_PRODUCT.url': ('hirise.html#url', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.IR_PRODUCT': ('hirise.html#ir_product', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.IR_PRODUCT.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID': ('hirise.html#obsid', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.__repr__': ('hirise.html#__repr__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.__str__': ('hirise.html#__str__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.id': ('hirise.html#id', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.orbit': ('hirise.html#orbit', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.phase': ('hirise.html#phase', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.storage_path_stem': ( 'hirise.html#storage_path_stem',
                                                                                    'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.targetcode': ('hirise.html#targetcode', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.OBSID.upper_orbit_folder': ( 'hirise.html#upper_orbit_folder',
                                                                                     'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder': ('hirise.html#productpathfinder', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.__getattr__': ( 'hirise.html#__getattr__',
                                                                                          'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.__repr__': ('hirise.html#__repr__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.__str__': ('hirise.html#__str__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder._make_url': ('hirise.html#_make_url', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.abrowse_path': ( 'hirise.html#abrowse_path',
                                                                                           'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.browse_path': ( 'hirise.html#browse_path',
                                                                                          'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.download_label': ( 'hirise.html#download_label',
                                                                                             'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.edr_storage_stem': ( 'hirise.html#edr_storage_stem',
                                                                                               'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.from_path': ('hirise.html#from_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.go_to_homepage': ( 'hirise.html#go_to_homepage',
                                                                                             'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.homepage': ('hirise.html#homepage', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.jp2_fname': ('hirise.html#jp2_fname', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.jp2_path': ('hirise.html#jp2_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.kind': ('hirise.html#kind', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.label_fname': ( 'hirise.html#label_fname',
                                                                                          'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.label_path': ('hirise.html#label_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.local_label_path': ( 'hirise.html#local_label_path',
                                                                                               'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.nomap_browse_path': ( 'hirise.html#nomap_browse_path',
                                                                                                'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.nomap_jp2_path': ( 'hirise.html#nomap_jp2_path',
                                                                                             'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.nomap_thumbnail_path': ( 'hirise.html#nomap_thumbnail_path',
                                                                                                   'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.obsid': ('hirise.html#obsid', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.product_id': ('hirise.html#product_id', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.quicklook_path': ( 'hirise.html#quicklook_path',
                                                                                             'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.storage_stem': ( 'hirise.html#storage_stem',
                                                                                           'planetarypy/hirise.py'),
                                    'planetarypy.hirise.ProductPathfinder.thumbnail_path': ( 'hirise.html#thumbnail_path',
                                                                                             'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RED_PRODUCT': ('hirise.html#red_product', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RED_PRODUCT.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAP': ('hirise.html#rgb_nomap', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAP.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAPCollection': ('hirise.html#rgb_nomapcollection', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAPCollection.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAPCollection.download_collection': ( 'hirise.html#download_collection',
                                                                                                    'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAPCollection.get_urls': ('hirise.html#get_urls', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.RGB_NOMAPCollection.local_paths': ( 'hirise.html#local_paths',
                                                                                            'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT': ('hirise.html#source_product', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.__getattr__': ('hirise.html#__getattr__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.__init__': ('hirise.html#__init__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.__repr__': ('hirise.html#__repr__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.__str__': ('hirise.html#__str__', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT._parse_ccd': ('hirise.html#_parse_ccd', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.ccd': ('hirise.html#ccd', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.ccdno': ('hirise.html#ccdno', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.channel': ('hirise.html#channel', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.color': ('hirise.html#color', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.download': ('hirise.html#download', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.fname': ('hirise.html#fname', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.local_cube': ('hirise.html#local_cube', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.local_path': ('hirise.html#local_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.remote_path': ('hirise.html#remote_path', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.spid': ('hirise.html#spid', 'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.stitched_cube_name': ( 'hirise.html#stitched_cube_name',
                                                                                              'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.stitched_cube_path': ( 'hirise.html#stitched_cube_path',
                                                                                              'planetarypy/hirise.py'),
                                    'planetarypy.hirise.SOURCE_PRODUCT.url': ('hirise.html#url', 'planetarypy/hirise.py')},
            'planetarypy.pds.apps': { 'planetarypy.pds.apps.find_indexes': ('pds.apps.html#find_indexes', 'planetarypy/pds/apps.py'),
                                      'planetarypy.pds.apps.find_instruments': ( 'pds.apps.html#find_instruments',
                                                                                 'planetarypy/pds/apps.py'),
                                      'planetarypy.pds.apps.get_index': ('pds.apps.html#get_index', 'planetarypy/pds/apps.py'),
                                      'planetarypy.pds.apps.refresh_index': ('pds.apps.html#refresh_index', 'planetarypy/pds/apps.py')},
            'planetarypy.pds.ctx_index': { 'planetarypy.pds.ctx_index.CTXIndex': ( 'pds.ctx_index.html#ctxindex',
                                                                                   'planetarypy/pds/ctx_index.py'),
                                           'planetarypy.pds.ctx_index.CTXIndex.latest_index_label_url': ( 'pds.ctx_index.html#latest_index_label_url',
                                                                                                          'planetarypy/pds/ctx_index.py'),
                                           'planetarypy.pds.ctx_index.CTXIndex.latest_volume_url': ( 'pds.ctx_index.html#latest_volume_url',
                                                                                                     'planetarypy/pds/ctx_index.py'),
                                           'planetarypy.pds.ctx_index.CTXIndex.release_number': ( 'pds.ctx_index.html#release_number',
                                                                                                  'planetarypy/pds/ctx_index.py'),
                                           'planetarypy.pds.ctx_index.CTXIndex.release_url': ( 'pds.ctx_index.html#release_url',
                                                                                               'planetarypy/pds/ctx_index.py'),
                                           'planetarypy.pds.ctx_index.CTXIndex.web_tables_list': ( 'pds.ctx_index.html#web_tables_list',
                                                                                                   'planetarypy/pds/ctx_index.py')},
            'planetarypy.pds.indexes': { 'planetarypy.pds.indexes.Index': ('pds.indexes.html#index', 'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.__init__': ( 'pds.indexes.html#__init__',
                                                                                     'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.__repr__': ( 'pds.indexes.html#__repr__',
                                                                                     'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.__str__': ( 'pds.indexes.html#__str__',
                                                                                    'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.convert_to_hdf': ( 'pds.indexes.html#convert_to_hdf',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.convert_to_parquet': ( 'pds.indexes.html#convert_to_parquet',
                                                                                               'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.df': ('pds.indexes.html#df', 'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.download': ( 'pds.indexes.html#download',
                                                                                     'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.index_name': ( 'pds.indexes.html#index_name',
                                                                                       'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.instrument': ( 'pds.indexes.html#instrument',
                                                                                       'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.instrument_key': ( 'pds.indexes.html#instrument_key',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.isotimestamp': ( 'pds.indexes.html#isotimestamp',
                                                                                         'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.isupper': ( 'pds.indexes.html#isupper',
                                                                                    'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.key_tokens': ( 'pds.indexes.html#key_tokens',
                                                                                       'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.label': ('pds.indexes.html#label', 'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.label_filename': ( 'pds.indexes.html#label_filename',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.label_path': ( 'pds.indexes.html#label_path',
                                                                                       'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.local_dir': ( 'pds.indexes.html#local_dir',
                                                                                      'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.local_hdf_path': ( 'pds.indexes.html#local_hdf_path',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.local_label_path': ( 'pds.indexes.html#local_label_path',
                                                                                             'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.local_parq_path': ( 'pds.indexes.html#local_parq_path',
                                                                                            'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.local_table_path': ( 'pds.indexes.html#local_table_path',
                                                                                             'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.mission': ( 'pds.indexes.html#mission',
                                                                                    'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.mission_key': ( 'pds.indexes.html#mission_key',
                                                                                        'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.needs_download': ( 'pds.indexes.html#needs_download',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.parquet': ( 'pds.indexes.html#parquet',
                                                                                    'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.parse_key': ( 'pds.indexes.html#parse_key',
                                                                                      'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.read_index_data': ( 'pds.indexes.html#read_index_data',
                                                                                            'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.set_hdf_available': ( 'pds.indexes.html#set_hdf_available',
                                                                                              'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.set_parquet_available': ( 'pds.indexes.html#set_parquet_available',
                                                                                                  'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.set_url': ( 'pds.indexes.html#set_url',
                                                                                    'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.table_filename': ( 'pds.indexes.html#table_filename',
                                                                                           'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.table_path': ( 'pds.indexes.html#table_path',
                                                                                       'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.table_url': ( 'pds.indexes.html#table_url',
                                                                                      'planetarypy/pds/indexes.py'),
                                         'planetarypy.pds.indexes.Index.update_timestamp': ( 'pds.indexes.html#update_timestamp',
                                                                                             'planetarypy/pds/indexes.py')},
            'planetarypy.pds.lroc_index': { 'planetarypy.pds.lroc_index.LROCIndex': ( 'pds.lroc_index.html#lrocindex',
                                                                                      'planetarypy/pds/lroc_index.py'),
                                            'planetarypy.pds.lroc_index.LROCIndex.__init__': ( 'pds.lroc_index.html#__init__',
                                                                                               'planetarypy/pds/lroc_index.py')},
            'planetarypy.pds.opusapi': { 'planetarypy.pds.opusapi.OPUS': ('pds.opusapi.html#opus', 'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.__init__': ( 'pds.opusapi.html#__init__',
                                                                                    'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS._get_time_query': ( 'pds.opusapi.html#_get_time_query',
                                                                                           'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.create_files_request': ( 'pds.opusapi.html#create_files_request',
                                                                                                'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.create_images_request': ( 'pds.opusapi.html#create_images_request',
                                                                                                 'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.create_request_with_query': ( 'pds.opusapi.html#create_request_with_query',
                                                                                                     'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.download_previews': ( 'pds.opusapi.html#download_previews',
                                                                                             'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.download_results': ( 'pds.opusapi.html#download_results',
                                                                                            'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.get_between_resolutions': ( 'pds.opusapi.html#get_between_resolutions',
                                                                                                   'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.get_between_times': ( 'pds.opusapi.html#get_between_times',
                                                                                             'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.get_radial_res_query': ( 'pds.opusapi.html#get_radial_res_query',
                                                                                                'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.get_volume_id': ( 'pds.opusapi.html#get_volume_id',
                                                                                         'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.query_image_id': ( 'pds.opusapi.html#query_image_id',
                                                                                          'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.response': ( 'pds.opusapi.html#response',
                                                                                    'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.show_images': ( 'pds.opusapi.html#show_images',
                                                                                       'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUS.unpack_json_response': ( 'pds.opusapi.html#unpack_json_response',
                                                                                                'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSImageURL': ( 'pds.opusapi.html#opusimageurl',
                                                                                   'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSImageURL.__init__': ( 'pds.opusapi.html#__init__',
                                                                                            'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSImageURL.__repr__': ( 'pds.opusapi.html#__repr__',
                                                                                            'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID': ('pds.opusapi.html#opusobsid', 'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.__init__': ( 'pds.opusapi.html#__init__',
                                                                                         'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.__repr__': ( 'pds.opusapi.html#__repr__',
                                                                                         'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID._get_img_url': ( 'pds.opusapi.html#_get_img_url',
                                                                                             'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.all_urls': ( 'pds.opusapi.html#all_urls',
                                                                                         'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.calib_urls': ( 'pds.opusapi.html#calib_urls',
                                                                                           'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.full_img_url': ( 'pds.opusapi.html#full_img_url',
                                                                                             'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.get_meta_data': ( 'pds.opusapi.html#get_meta_data',
                                                                                              'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.img_id': ( 'pds.opusapi.html#img_id',
                                                                                       'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.medium_img_url': ( 'pds.opusapi.html#medium_img_url',
                                                                                               'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.raw_urls': ( 'pds.opusapi.html#raw_urls',
                                                                                         'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.small_img_url': ( 'pds.opusapi.html#small_img_url',
                                                                                              'planetarypy/pds/opusapi.py'),
                                         'planetarypy.pds.opusapi.OPUSObsID.thumb_img_url': ( 'pds.opusapi.html#thumb_img_url',
                                                                                              'planetarypy/pds/opusapi.py')},
            'planetarypy.pds.utils': { 'planetarypy.pds.utils.IndexLabel': ('pds.utils.html#indexlabel', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.__init__': ('pds.utils.html#__init__', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.colnames': ('pds.utils.html#colnames', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.colspecs': ('pds.utils.html#colspecs', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.columns_dic': ( 'pds.utils.html#columns_dic',
                                                                                         'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.index_path': ( 'pds.utils.html#index_path',
                                                                                        'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.pvl_columns': ( 'pds.utils.html#pvl_columns',
                                                                                         'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.pvl_lbl': ('pds.utils.html#pvl_lbl', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.read_index_data': ( 'pds.utils.html#read_index_data',
                                                                                             'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.IndexLabel.table': ('pds.utils.html#table', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn': ('pds.utils.html#pvlcolumn', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.__init__': ('pds.utils.html#__init__', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.__repr__': ('pds.utils.html#__repr__', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.colspecs': ('pds.utils.html#colspecs', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.decode': ('pds.utils.html#decode', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.item_bytes': ( 'pds.utils.html#item_bytes',
                                                                                       'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.item_offset': ( 'pds.utils.html#item_offset',
                                                                                        'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.items': ('pds.utils.html#items', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.name': ('pds.utils.html#name', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.name_as_list': ( 'pds.utils.html#name_as_list',
                                                                                         'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.start': ('pds.utils.html#start', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.PVLColumn.stop': ('pds.utils.html#stop', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.decode_line': ('pds.utils.html#decode_line', 'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.find_mixed_type_cols': ( 'pds.utils.html#find_mixed_type_cols',
                                                                                       'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.fix_hirise_edrcumindex': ( 'pds.utils.html#fix_hirise_edrcumindex',
                                                                                         'planetarypy/pds/utils.py'),
                                       'planetarypy.pds.utils.index_to_df': ('pds.utils.html#index_to_df', 'planetarypy/pds/utils.py')},
            'planetarypy.spice.kernels': { 'planetarypy.spice.kernels.Subsetter': ( 'spice.kernels.html#subsetter',
                                                                                    'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.__init__': ( 'spice.kernels.html#__init__',
                                                                                             'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter._get_payload': ( 'spice.kernels.html#_get_payload',
                                                                                                 'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter._non_blocking_download': ( 'spice.kernels.html#_non_blocking_download',
                                                                                                           'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.download_kernels': ( 'spice.kernels.html#download_kernels',
                                                                                                     'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.get_local_path': ( 'spice.kernels.html#get_local_path',
                                                                                                   'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.get_metakernel': ( 'spice.kernels.html#get_metakernel',
                                                                                                   'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.kernel_names': ( 'spice.kernels.html#kernel_names',
                                                                                                 'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.start': ( 'spice.kernels.html#start',
                                                                                          'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.Subsetter.stop': ( 'spice.kernels.html#stop',
                                                                                         'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.get_metakernel_and_files': ( 'spice.kernels.html#get_metakernel_and_files',
                                                                                                   'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.is_start_valid': ( 'spice.kernels.html#is_start_valid',
                                                                                         'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.is_stop_valid': ( 'spice.kernels.html#is_stop_valid',
                                                                                        'planetarypy/spice/kernels.py'),
                                           'planetarypy.spice.kernels.list_kernels_for_day': ( 'spice.kernels.html#list_kernels_for_day',
                                                                                               'planetarypy/spice/kernels.py')},
            'planetarypy.utils': { 'planetarypy.utils._nasa_date_to_datetime': ( 'utils.html#_nasa_date_to_datetime',
                                                                                 'planetarypy/utils.py'),
                                   'planetarypy.utils._nasa_datetime_to_datetime': ( 'utils.html#_nasa_datetime_to_datetime',
                                                                                     'planetarypy/utils.py'),
                                   'planetarypy.utils._nasa_datetimems_to_datetime': ( 'utils.html#_nasa_datetimems_to_datetime',
                                                                                       'planetarypy/utils.py'),
                                   'planetarypy.utils.check_url_exists': ('utils.html#check_url_exists', 'planetarypy/utils.py'),
                                   'planetarypy.utils.file_variations': ('utils.html#file_variations', 'planetarypy/utils.py'),
                                   'planetarypy.utils.get_gdal_center_coords': ( 'utils.html#get_gdal_center_coords',
                                                                                 'planetarypy/utils.py'),
                                   'planetarypy.utils.get_remote_timestamp': ('utils.html#get_remote_timestamp', 'planetarypy/utils.py'),
                                   'planetarypy.utils.have_internet': ('utils.html#have_internet', 'planetarypy/utils.py'),
                                   'planetarypy.utils.height_from_shadow': ('utils.html#height_from_shadow', 'planetarypy/utils.py'),
                                   'planetarypy.utils.iso_to_nasa_datetime': ('utils.html#iso_to_nasa_datetime', 'planetarypy/utils.py'),
                                   'planetarypy.utils.iso_to_nasa_time': ('utils.html#iso_to_nasa_time', 'planetarypy/utils.py'),
                                   'planetarypy.utils.nasa_time_to_datetime': ('utils.html#nasa_time_to_datetime', 'planetarypy/utils.py'),
                                   'planetarypy.utils.nasa_time_to_iso': ('utils.html#nasa_time_to_iso', 'planetarypy/utils.py'),
                                   'planetarypy.utils.parse_http_date': ('utils.html#parse_http_date', 'planetarypy/utils.py'),
                                   'planetarypy.utils.replace_all_nasa_times': ( 'utils.html#replace_all_nasa_times',
                                                                                 'planetarypy/utils.py'),
                                   'planetarypy.utils.url_retrieve': ('utils.html#url_retrieve', 'planetarypy/utils.py')},
            'planetarypy.uvis': { 'planetarypy.uvis.DataManager': ('cassini_uvis.html#datamanager', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.__init__': ('cassini_uvis.html#__init__', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.__repr__': ('cassini_uvis.html#__repr__', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.calib_corr_path': ( 'cassini_uvis.html#calib_corr_path',
                                                                                    'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.calib_label_path': ( 'cassini_uvis.html#calib_label_path',
                                                                                     'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.download': ('cassini_uvis.html#download', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.folder': ('cassini_uvis.html#folder', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.original_pid_file': ( 'cassini_uvis.html#original_pid_file',
                                                                                      'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.pds_id': ('cassini_uvis.html#pds_id', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.query': ('cassini_uvis.html#query', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.raw_data_path': ('cassini_uvis.html#raw_data_path', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.raw_data_url': ('cassini_uvis.html#raw_data_url', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.raw_label_path': ( 'cassini_uvis.html#raw_label_path',
                                                                                   'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.raw_label_url': ('cassini_uvis.html#raw_label_url', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.DataManager.results_file': ('cassini_uvis.html#results_file', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.get_data_path': ('cassini_uvis.html#get_data_path', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.get_label_path': ('cassini_uvis.html#get_label_path', 'planetarypy/uvis.py'),
                                  'planetarypy.uvis.get_user_guide': ('cassini_uvis.html#get_user_guide', 'planetarypy/uvis.py')}}}


# AUTOGENERATED! DO NOT EDIT! File to edit: ../../notebooks/02f_pds.utils.ipynb.

# %% auto 0
__all__ = ['IndexLabel', 'index_to_df', 'PVLColumn', 'decode_line', 'find_mixed_type_cols', 'fix_hirise_edrcumindex']

# %% ../../notebooks/02f_pds.utils.ipynb 3
from typing import Union
from tqdm.auto import tqdm
from fastcore.utils import Path

import pandas as pd
import pvl
from .. import utils

# %% ../../notebooks/02f_pds.utils.ipynb 4
class IndexLabel:
    "Support working with label files of PDS Index tables."

    def __init__(
        self,
        # Path to the labelfile for a PDS Indexfile.
        # The actual table should reside in the same folder to be automatically parsed
        # when calling the `read_index_data` method.
        labelpath: Union[str, Path],
    ):
        self.path = Path(labelpath)
        "search for table name pointer and store key and fpath."
        tuple = [i for i in self.pvl_lbl if i[0].startswith("^")][0]
        self.tablename = tuple[0][1:]
        self.index_name = tuple[1]

    @property
    def index_path(self):
        p = self.path.parent / self.index_name
        if not p.exists():
            import warnings

            warnings.warn(
                "Fudging path name to lower case, opposing label value. (PDS data inconsistency)"
            )
            p = self.path.parent / self.index_name.lower()
        if not p.exists():
            warnings.warn("`index_path` still doesn't exist.")
        return p

    @property
    def pvl_lbl(self):
        return pvl.load(str(self.path))

    @property
    def table(self):
        return self.pvl_lbl[self.tablename]

    @property
    def pvl_columns(self):
        return self.table.getlist("COLUMN")

    @property
    def columns_dic(self):
        return {col["NAME"]: col for col in self.pvl_columns}

    @property
    def colnames(self):
        """Read the columns in an PDS index label file.

        The label file for the PDS indices describes the content
        of the index files.
        """
        colnames = []
        for col in self.pvl_columns:
            colnames.extend(PVLColumn(col).name_as_list)
        return colnames

    @property
    def colspecs(self):
        colspecs = []
        columns = self.table.getlist("COLUMN")
        for column in columns:
            pvlcol = PVLColumn(column)
            if pvlcol.items is None:
                colspecs.append(pvlcol.colspecs)
            else:
                colspecs.extend(pvlcol.colspecs)
        return colspecs

    def read_index_data(self, convert_times=True):
        return index_to_df(self.index_path, self, convert_times=convert_times)

# %% ../../notebooks/02f_pds.utils.ipynb 5
def index_to_df(
    # Path to the index TAB file
    indexpath: Union[str, Path],
    # Label object that has both the column names and the columns widths as attributes
    # 'colnames' and 'colspecs'
    label: IndexLabel,
    # Switch to control if to convert columns with "TIME" in name (unless COUNT is as well in name) to datetime
    convert_times=True,
):
    """The main reader function for PDS Indexfiles.

    In conjunction with an IndexLabel object that figures out the column widths,
    this reader should work for all PDS TAB files.
    """
    indexpath = Path(indexpath)
    df = pd.read_fwf(
        indexpath, header=None, names=label.colnames, colspecs=label.colspecs
    )
    if convert_times:
        for column in [col for col in df.columns if "TIME" in col]:
            if column in ["LOCAL_TIME", "DWELL_TIME"]:
                continue
            try:
                df[column] = pd.to_datetime(df[column])
            except ValueError:
                df[column] = pd.to_datetime(
                    df[column], format=utils.nasa_dt_format_with_ms, errors="coerce"
                )
            except KeyError:
                raise KeyError(f"{column} not in {df.columns}")
        print("Done.")
    return df

# %% ../../notebooks/02f_pds.utils.ipynb 6
class PVLColumn:
    "Manages just one of the columns in a table that is described via PVL."

    def __init__(self, pvlobj):
        self.pvlobj = pvlobj

    @property
    def name(self):
        return self.pvlobj["NAME"]

    @property
    def name_as_list(self):
        "needs to return a list for consistency for cases when it's an array."
        if self.items is None:
            return [self.name]
        else:
            return [self.name + "_" + str(i + 1) for i in range(self.items)]

    @property
    def start(self):
        "Decrease by one as Python is 0-indexed."
        return self.pvlobj["START_BYTE"] - 1

    @property
    def stop(self):
        return self.start + self.pvlobj["BYTES"]

    @property
    def items(self):
        return self.pvlobj.get("ITEMS")

    @property
    def item_bytes(self):
        return self.pvlobj.get("ITEM_BYTES")

    @property
    def item_offset(self):
        return self.pvlobj.get("ITEM_OFFSET")

    @property
    def colspecs(self):
        if self.items is None:
            return (self.start, self.stop)
        else:
            i = 0
            bucket = []
            for _ in range(self.items):
                off = self.start + self.item_offset * i
                bucket.append((off, off + self.item_bytes))
                i += 1
            return bucket

    def decode(self, linedata):
        if self.items is None:
            start, stop = self.colspecs
            return linedata[start:stop]
        else:
            bucket = []
            for (start, stop) in self.colspecs:
                bucket.append(linedata[start:stop])
            return bucket

    def __repr__(self):
        return self.pvlobj.__repr__()

# %% ../../notebooks/02f_pds.utils.ipynb 7
def decode_line(
    linedata: str,  # One line of a .tab data file
    labelpath: Union[
        str, Path
    ],  # Path to the appropriate label that describes the data.
):
    "Decode one line of tabbed data with the appropriate label file."
    label = IndexLabel(labelpath)
    for column in label.pvl_columns:
        pvlcol = PVLColumn(column)
        print(pvlcol.name, pvlcol.decode(linedata))

# %% ../../notebooks/02f_pds.utils.ipynb 8
def find_mixed_type_cols(
    # Dataframe to be searched for mixed data-types
    df: pd.DataFrame,
    # Switch to control if NaN values in these problem columns should be replaced by the string 'UNKNOWN'
    fix: bool = True,
) -> list:  # List of column names that have data type changes within themselves.
    """For a given dataframe, find the columns that are of mixed type.

    Tool to help with the performance warning when trying to save a pandas DataFrame as a HDF.
    When a column changes datatype somewhere, pickling occurs, slowing down the reading process of the HDF file.
    """
    result = []
    for col in df.columns:
        weird = (df[[col]].applymap(type) != df[[col]].iloc[0].apply(type)).any(axis=1)
        if len(df[weird]) > 0:
            print(col)
            result.append(col)
    if fix is True:
        for col in result:
            df[col].fillna("UNKNOWN", inplace=True)
    return result

# %% ../../notebooks/02f_pds.utils.ipynb 9
def fix_hirise_edrcumindex(
    infname: Union[str, Path],  # Path to broken EDRCUMINDEX.TAB
    outfname: Union[str, Path],  # Path where to store the fixed TAB file
):
    """Fix HiRISE EDRCUMINDEX.

    The HiRISE EDRCUMINDEX has some broken lines where the SCAN_EXPOSURE_DURATION is of format
    F10.4 instead of the defined F9.4.
    This function simply replaces those incidences with one less decimal fraction, so 20000.0000
    becomes 20000.000.
    """
    with Path(infname).open() as f:
        with Path(outfname).open("w") as newf:
            for line in tqdm(f):
                exp = line.split(",")[21]
                if float(exp) > 9999.999:
                    # catching the return of write into dummy variable
                    _ = newf.write(line.replace(exp, exp[:9]))
                else:
                    _ = newf.write(line)
